# -*- coding: utf-8 -*-

# Curlew - Easy to use multimedia converter
#
# Copyright (C) 2012-2015 Fayssal Chamekh <chamfay@gmail.com>
#
# Released under terms on waqf public license.
#
# Curlew is free software; you can redistribute it and/or modify it 
# under the terms of the latest version waqf public license as published by 
# ojuba.org.
#
# Curlew is distributed in the hope that it will be useful, but WITHOUT 
# ANY WARRANTY; without even the implied warranty 
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#        
# The latest version of the license can be found on:
# http://www.ojuba.org/wiki/doku.php/waqf/license

from gi.repository import Gtk


class Formats(Gtk.Dialog):
    def __init__(self, parent, formats_list, curr_format):
        
        self.selected_format = curr_format
        self.formats_list = formats_list
        
        Gtk.Dialog.__init__(self, parent=parent)
        self.set_title(_('Choose a format'))
        
        #
        self.e_search = Gtk.SearchEntry()
        self.e_search.set_activates_default(True)
        self.e_search.connect('changed', self.on_entry_search)
        self.e_search.set_direction(Gtk.TextDirection.LTR)
        self.vbox.pack_start(self.e_search, False, True, 2)
        self.set_size_request(350, 400)
        self.set_border_width(2)
        
        self.vbox.set_spacing(4)
        
        #
        self.store = Gtk.ListStore(str)
        self.tree_filter = self.store.filter_new()
        self.tree_filter.set_visible_func(self.match_func)
        self.tree_formats = Gtk.TreeView(self.tree_filter)
        self.tree_formats.set_headers_visible(False)
        self.tree_formats.set_direction(Gtk.TextDirection.LTR)
        self.tree_formats.set_grid_lines(Gtk.TreeViewGridLines.HORIZONTAL)
        self.tree_formats.connect('row-activated', self.on_choosed_format)
        
        # cell
        cell = Gtk.CellRendererText()
        col = Gtk.TreeViewColumn(None, cell, text=0)
        self.tree_formats.append_column(col)
        
        scroll = Gtk.ScrolledWindow()
        scroll.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
        scroll.add(self.tree_formats)
        self.vbox.pack_start(scroll, True, True, 0)
        
        # Load formats
        for fmt in self.formats_list:
            self.store.append([fmt])
        
        # Show all
        self.show_all()
        
    def on_entry_search(self, w):
        self.tree_filter.refilter()
    
    def match_func(self, model, tree_iter, data=None):
        txt = self.e_search.get_text()
        value = model.get_value(tree_iter, 0)
        
        if (txt == "") or (txt.lower() in value.lower()):
            return True
        self.tree_formats.set_cursor(0)
        return False
    
    def on_choosed_format(self, tree, path, col):
        model = tree.get_model()
        self.selected_format = model[path][0]        
        self.close()


